@@ -25,20 +25,19 @@ class GetOrderDetailRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'GetOrderDetail','bssopenapi')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_OrderId(self):
+	def get_OrderId(self): # String
 		return self.get_query_params().get('OrderId')
 
-	def set_OrderId(self,OrderId):
-		self.add_query_param('OrderId',OrderId)
-
-	def get_OwnerId(self):
+	def set_OrderId(self, OrderId):  # String
+		self.add_query_param('OrderId', OrderId)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
